@@ -58,7 +58,7 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     if(dateTime.toString("ddd") == "Sun")
         week = "星期日";
 
-    currentTime = dateTime.toString("yyyy-MM-dd %1").arg(week);
+    currentTime = dateTime.toString("yyyy-MM-dd");
     QDate day = QDate::currentDate();
     struct CCalendar datebase;
     mycalendat->ctcl_solar_to_lunar(day.year(),day.month(),day.day(),&datebase);
@@ -853,7 +853,7 @@ void ChineseCalendar::resetcalendardate(QString day)
         weekday = "星期六";
     if(date.toString("ddd") == "Sun")
         weekday = "星期日";
-    QString selecttime = date.toString("yyyy-MM-dd %1").arg(weekday);
+    QString selecttime = date.toString("yyyy-MM-dd");
     struct CCalendar d;
     mycalendat->ctcl_solar_to_lunar(date.year(),date.month(),date.day(),&d);
     QString selectmonth = d.cmonth;
